/*
 * Copyright (C) 2012-2013 The Dojo Foundation
 * 
 * Copyright (C) 2012-2013 Rex Young
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package com.fastmessenger.impl;

class Address {

    private String activeobject, service;
    private int hash = 0;

    Address (String fullyQualifiedServiceName) {

        String fullName = fullyQualifiedServiceName;

        int position = fullName.indexOf ("::");
        if (position > -1) {
            fullName = fullName.substring (position + 2);

            String messengerId = fullName.substring (0, position).trim ();
            if (!messengerId.isEmpty ()) {
                throw new IllegalArgumentException ("Validation error: messengerId not supported : "
                        + fullyQualifiedServiceName);
            }
        }

        position = fullName.indexOf (":");
        if (position == -1) {
            activeobject = fullName.trim ();
            service = "";
        } else {
            activeobject = fullName.substring (0, position).trim ();
            service = fullName.substring (position + 1).trim ();
        }

        Utils.chkNonEmptyId (this.activeobject);
        Utils.chkEmptyOkId (this.service);
    }

    Address (String activeobject, String service) {

        this.activeobject = activeobject.trim ();
        this.service = service.trim ();

        Utils.chkNonEmptyId (this.activeobject);
        Utils.chkEmptyOkId (this.service);
    }

    void setActiveobject (String activeobject) {
        this.activeobject = activeobject;
    }

    String getActiveobject () {
        return activeobject;
    }

    void setService (String service) {
        this.service = service;
    }

    String getService () {
        return service;
    }

    public boolean equals (Object obj) {
        if (this == obj) {
            return true;
        } else if (obj instanceof Address) {
            Address that = (Address) obj;
            return this.activeobject.equals (that.activeobject) && this.service.equals (that.service);
        } else {
            return false;
        }
    }

    public int hashCode () {
        if (hash == 0) {
            hash = toString ().hashCode ();
        }
        return hash;
    }

    public String toString () {
        return activeobject + ":" + service;
    }

}
