/*
 * Copyright (C) 2012-2013 The Dojo Foundation
 * 
 * Copyright (C) 2012-2013 Rex Young
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package com.fastmessenger.impl;

import java.lang.reflect.Method;
import java.util.HashMap;

class ReceiverManager {

    private HashMap<String, ReceiverMailbox> receiverMailboxMap = new HashMap<String, ReceiverMailbox> ();

    void addReceiver (String receiver, Messenger messenger, ReceiverType type, Object[] implObjs) {

        switch (type) {
        case NonGui:
            receiverMailboxMap.put (receiver, new ReceiverMailbox (messenger, implObjs));
            break;
        case JavaFX:
            receiverMailboxMap.put (receiver, new JavaFxReceiverMailbox (messenger, implObjs));
            break;
        case Swing:
            receiverMailboxMap.put (receiver, new SwingReceiverMailbox (messenger, implObjs));
            break;
        case SWT:
            receiverMailboxMap.put (receiver, new SwtReceiverMailbox ((GuiMessenger) messenger, implObjs));
            break;
        }
    }

    void removeReceiver (String receiver) {

        receiverMailboxMap.remove (receiver).stop ();
    }

    Method findServiceMethodIfAny (Address receiverAddress, Object... serviceArguments) {

        ReceiverMailbox receiverMailbox = receiverMailboxMap.get (receiverAddress.getActiveobject ());

        return receiverMailbox.findServiceMethodIfAny (receiverAddress.getService (), serviceArguments);
    }

    void addServiceRequest (ServiceRequest request) {

        ReceiverMailbox receiverMailbox = receiverMailboxMap.get (request.getServiceAddress ()
                .getActiveobject ());

        receiverMailbox.addServiceRequest (request);
    }

}
