/*
 * Copyright (C) 2012-2013 The Dojo Foundation
 * 
 * Copyright (C) 2012-2013 Rex Young
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package com.fastmessenger.impl;

import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.List;

class RouteManager {

    private HashMap<Address, List<Address>> routeMap = new HashMap<Address, List<Address>> ();
    private HashSet<String> routeKeySet = new HashSet<String> ();

    void addRoute (Address senderAddress, Address receiverAddress) {

        String routeKey = senderAddress + ">>" + receiverAddress;

        if (routeKeySet.add (routeKey)) {

            List<Address> receiverAddressList = routeMap.get (senderAddress);

            if (receiverAddressList == null) {
                receiverAddressList = new LinkedList<Address> ();
                routeMap.put (senderAddress, receiverAddressList);
            }

            receiverAddressList.add (receiverAddress);
        }
    }

    void removeRoute (Address senderAddress, Address receiverAddress) {

        String routeKey = senderAddress + ">>" + receiverAddress;

        if (routeKeySet.remove (routeKey)) {

            List<Address> receiverAddressList = routeMap.get (senderAddress);

            receiverAddressList.remove (receiverAddress);

            if (receiverAddressList.isEmpty ()) {
                routeMap.remove (senderAddress);
            }
        }
    }

    List<Address> getReceiversBySender (Address senderAddress) {

        return routeMap.get (senderAddress);
    }

}
