/*
 * Copyright (C) 2012-2013 The Dojo Foundation
 * 
 * Copyright (C) 2012-2013 Rex Young
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package com.fastmessenger.model;

/**
 * This is a marker interface. An object indicates by implementing the interface that it prefers to
 * receive service requests from a messenger at the onServiceRequest() method.
 * 
 * @author Rex Young
 */
public interface IReceiver {

    /**
     * This method receives all service requests from a messenger that will guarantee the method a
     * single-threaded runtime context. It means the messenger will invoke this method with one
     * service request after a previous invocation is completed.
     * 
     * @param service
     *            simple service name
     * @param serviceArguments
     *            arguments for the service
     * @return the return value
     */
    Object onServiceRequest (String service, Object... serviceArguments);

}
