/*
 * Copyright (C) 2012-2013 The Dojo Foundation
 * 
 * Copyright (C) 2012-2013 Rex Young
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package com.fastmessenger.model;

/**
 * This object represents the deferred result of a service request. All service requests submitted
 * to a messenger will be executed independently to their callers. This object is the only token
 * through which a caller can either query (non-blocking) whether the result is returned, or wait
 * (blocking) until the result is returned.
 * 
 * @author Rex Young
 * 
 * @param <T>
 *            The type of return value
 */
public interface IReturn<T> {

    /**
     * Returns true if the service request is completed. However it does not tell whether the
     * request is completed normally or due to a runtime exception.
     * 
     * @return true if the service is completed
     */
    boolean isReturned ();

    /**
     * Waits if necessary for the service request to complete, and then returns the result. It may
     * throw a runtime exception if an exception happens during the execution of the service
     * request.
     * 
     * @return the return value
     */
    T get ();

    /**
     * Waits if necessary for at most of the given time for the service request to complete, and
     * then returns the result, if available. It may throw a runtime exception if an exception
     * happens during the execution of the service request.
     * 
     * @param timeoutMillis
     *            the maximum milliseconds to wait
     * @return the return value
     */
    T get (long timeoutMillis);

}
